/* -- AIX/6000 System monitor 
**
**     get_cpuinfo.h
**
** Copyright (c) 1993-2001 Marcel Mol, All Rights Reserved.
** Copyright (c) 1991-1995 Jussi Maki, All Rights Reserved.
** NON-COMMERCIAL USE ALLOWED. YOU ARE FREE TO DISTRIBUTE
** THIS PROGRAM AND MODIFY IT AS LONG AS YOU KEEP ORIGINAL
** COPYRIGHTS.
*/

#include <sys/types.h>
#include <sys/sysinfo.h>

#define MAX_CPUS	64

#if AIX_NUM < 4000000
struct cpuinfo {
  int dummy;
};
#endif

int get_cpuinfo(struct cpuinfo **cpu);

/******************
  print_cpuinfo.h
*********************/

void calc_cpuinfo(double refresh_time,
                  struct cpuinfo *cpus1, struct cpuinfo *cpus2);
void print_cpuinfo_init();
void print_cpuinfo();
void log_cpuinfo_header();
void log_cpuinfo();
void max_cpuinfo_init();
void log_cpuinfo_max();


